/*
 * Test dataspace operations.
 *
 * Copyright (C) 2020, 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <systypes/fcntl.h>

#include <stdio.h>

#include <fsclient/client.h>

#include <e2access/fs.h>



int main(int argc, char *argv[])
{
  if (argc < 3)
  {
    printf("Need a device and filename.\n");
    return 1;
  }

  /* Obtain device, filename and access parameters. */

  char *device = argv[1];
  char *filename = argv[2];

  e2access_init(device);

  ext2_filsys fs = NULL;

  errcode_t retval = e2access_open(filename, EXT2_FLAG_RW, &fs); // EXT2_FLAG_SOFTSUPP_FEATURES | EXT2_FLAG_64BITS

  if (retval)
  {
    printf("Could not obtain filesystem: %ld.\n", retval);
    return 1;
  }

  printf("Access completed.\n");

  return 0;
}

// vim: tabstop=2 expandtab shiftwidth=2
